@@ -1,6 +1,6 @@
 from os.path import split, splitext, isfile, exists, join, isdir, abspath
 from os import listdir, makedirs, mkdir, remove, rmdir
-from .Children import Children
+from .Directory import Directory
 from .Abstrcat import Abstract
 from .btype import FILE, DIR
 import shutil
@@ -8,39 +8,12 @@ import shutil
 
 class Block:
 
-    def __init__(self, path: str) -> None:
+    def __init__(self, path: str):
         '''
             @parameter path - 文件/文件夹路径
         '''
         self.__path = path
     
-    def enter(self, path):
-        self.__path = self.join_path(path)
-    
-    @property
-    def path(self):
-        return self.__path
-    
-    @property
-    def abspath(self):
-        return abspath(self.path)
-    
-    @property
-    def directory(self):
-        return split(self.path)[0]
-    
-    @property
-    def file_full_name(self):
-        return split(self.path)[1]
-    
-    @property
-    def filename(self):
-        return splitext(self.file_full_name)[0]
-    
-    @property
-    def extension(self):
-        return splitext(self.file_full_name)[1]
-    
     def sub_block(self, path: str):
         '''
             @parameter path - 子文件或子文件夹的相对路径
@@ -128,31 +101,18 @@ class Block:
                         makedirs(path)
         return self
 
-    def search(self, name, type=None)->Children:
+    def search(self, name, type=None):
         '''
             在block内进行搜索，返回所有匹配的文件/文件夹
             
             可选参数type的值应为 fileblock.FILE 或 fileblock.DIR
         '''
         leaves = self.leaves
-        return [
+        return Directory([
             leaf for leaf in leaves
             if name in split(leaf.path)[1] and ((type is not None and leaf.btype==type) or type is None)
-        ]
+        ], copy=False)
     
-    @property
-    def leaves(self) -> Children:
-        '''
-        返回文件树中的所有叶子节点
-        '''
-        children = self.children
-        if len(children) > 0:
-            res = Children()
-            for child in children:
-                res.extend(child.leaves)
-            return res
-        else:
-            return Children([self])
 
     def cut(self, *rates):
         '''
@@ -168,7 +128,7 @@ class Block:
         n = children.__len__()
         cell = n / gross
         acc = 0
-        res = []
+        res = Directory(copy=False)
         rates_len = len(rates)
         for i in range(len(rates)):
             if rates_len == i + 1:
@@ -179,13 +139,68 @@ class Block:
                 acc += idx
         return res
     
-    def get_file_contents(self):
+    def get_file_contents(self, mode='rb', encoding=None):
         if self.isfile:
-            with open(self.path, 'rb') as f:
+            with open(self.path, 'rb', encoding=encoding) as f:
                 d = f.read()
             return d
         raise TypeError("This block is not a file-type block")
 
+    def enter(self, path):
+        self.__path = self.join_path(path)
+        return self
+
+    @property
+    def children(self):
+        res = Directory()
+        if self.isdir:
+            dirs = listdir(self.path)
+            for dir in dirs:
+                res.append(self.sub_block(dir))
+        return res
+
+    @property
+    def path(self):
+        return self.__path
+    
+    @property
+    def leaves(self):
+        '''
+        返回文件树中的所有叶子节点
+        '''
+        children = self.children
+        if len(children) > 0:
+            res = Directory()
+            for child in children:
+                res.extend(child.leaves)
+            return res
+        else:
+            return Directory([self])
+
+    @property
+    def abspath(self):
+        return abspath(self.path)
+    
+    @property
+    def directory(self):
+        return split(self.path)[0]
+    
+    @property
+    def file_full_name(self):
+        return split(self.path)[1]
+    
+    @property
+    def filename(self):
+        return splitext(self.file_full_name)[0]
+    
+    @property
+    def extension(self):
+        return splitext(self.file_full_name)[1]
+    
+    @property
+    def abstract(self, force_abspath=False):
+        return Abstract(self.btype, self.abspath if force_abspath else self.path)
+
     @property
     def isfile(self) -> bool:
         '''
@@ -208,22 +223,14 @@ class Block:
         return exists(self.path)
     
     @property
-    def children(self) -> Children:
-        res = Children()
-        if self.isdir:
-            dirs = listdir(self.path)
-            for dir in dirs:
-                res.append(self.sub_block(dir))
-        return res
+    def super_dir_name(self):
+        tmp = split(self.path)[0]
+        return split(tmp)[1]
 
-    
     @property
     def btype(self):
         return FILE if self.isfile else DIR if self.isdir else None
     
-    def abstract(self, force_abspath=False):
-        return Abstract(self.btype, self.abspath if force_abspath else self.path)
-
     def __str__(self):
         # return "(%s block: %s)" % (self.btype, self.path)
         return self.path
@@ -231,12 +238,6 @@ class Block:
     def __repr__(self) -> str:
         return self.__str__()
 
-    @property
-    def super_dir_name(self):
-        tmp = split(self.path)[0]
-        return split(tmp)[1]
-
-
 
 if __name__ == "__main__":
 
